ScyllaDbStoreInternalError

Enum ScyllaDbStoreInternalError 

pub enum ScyllaDbStoreInternalError {
Show 17 variants BcsError(Error), DeserializationError(DeserializationError), RowsError(RowsError), IntoRowsResultError(IntoRowsResultError), TypeCheckError(TypeCheckError), PagerExecutionError(PagerExecutionError), PrepareError(PrepareError), ExecutionError(ExecutionError), ExclusiveWriteBatchExecutionError(ExecutionError), SharedWriteBatchExecutionError(ExecutionError), NewSessionError(NewSessionError), NextRowError(NextRowError), InvalidNamespace, KeyTooLong, ValueTooLong, BatchTooLong, ZeroLengthKey,
}
The error type for ScyllaDbStoreInternal

Variants



BcsError(Error)

BCS serialization error.



DeserializationError(DeserializationError)

A deserialization error



RowsError(RowsError)

A row error



IntoRowsResultError(IntoRowsResultError)

A conversion error in the accessed data



TypeCheckError(TypeCheckError)

A type check error



PagerExecutionError(PagerExecutionError)

A pager execution error



PrepareError(PrepareError)

A prepare error



ExecutionError(ExecutionError)

An execution error during a query (except write-batch).



ExclusiveWriteBatchExecutionError(ExecutionError)

An execution error during a write-batch operation on a store opened in exclusive mode, which backs a view.



SharedWriteBatchExecutionError(ExecutionError)

An execution error during a write-batch operation on a store opened in shared mode, which backs no view.



NewSessionError(NewSessionError)

A session creation error



NextRowError(NextRowError)

A next row error in ScyllaDB



InvalidNamespace

Namespace contains forbidden characters



KeyTooLong

The key must have at most MAX_KEY_SIZE bytes



ValueTooLong

The value must have at most RAW_MAX_VALUE_SIZE bytes



BatchTooLong

The batch is too long to be written



ZeroLengthKey

Keys have to be of nonzero length (the empty key is reserved for the timestamp sentinel).